@@ -4,7 +4,7 @@
 @Author         : yanyongyu
 @Date           : 2020-11-23 18:44:18
 @LastEditors    : yanyongyu
-@LastEditTime   : 2020-11-23 22:15:27
+@LastEditTime   : 2021-06-10 23:48:15
 @Description    : None
 @GitHub         : https://github.com/yanyongyu
 """
@@ -12,14 +12,15 @@ __author__ = "yanyongyu"
 
 from typing import Any, List, Optional, Callable
 
-from pydantic import Field, BaseSettings
+from nonebot.log import logger
+
+from pydantic import Field, validator, BaseSettings
 
 
 class Config(BaseSettings):
-    sentry_dsn: str
+    sentry_dsn: Optional[str]
     sentry_debug: bool = False
     sentry_release: Optional[str] = None
-    sentry_release: Optional[str] = None
     sentry_environment: Optional[str] = None
     sentry_server_name: Optional[str] = None
     sentry_sample_rate: float = 1.
@@ -39,5 +40,11 @@ class Config(BaseSettings):
     sentry_https_proxy: Optional[str] = None
     sentry_shutdown_timeout: int = 2
 
+    @validator("sentry_dsn")
+    def validate_dsn(cls, v):
+        if not v:
+            logger.warning("Sentry DSN not provided! Sentry plugin disabled!")
+        return v
+
     class Config:
         extra = "ignore"
